"""
MIT License

Copyright (c) 2023 Wilhelm Ågren

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

File created: 2023-02-23
Last updated: 2023-02-23
"""

from __future__ import annotations

import builtins
String = builtins.str

from typing import Union, Any
from requests import Response

from gromp.endpoint.base import NamedEndpoint
from gromp.api.accounts import Accountv1Api

__all__ = (
    'Accountv1',
)

class Accountv1(NamedEndpoint):
    """
    There are three routing values for account-v1;
    americas, asia, and europe. 

    You can query for any account in any region. 
    We recommend using the nearest cluster.
    """

    def by_puuid(self, puuid: String) -> Union[Response, Any]:
        return self._request_api(
            Accountv1Api('by_puuid'),
            puuid=puuid,
        )

    def by_riot_id(self, game_name: String, tag_line: String) -> Union[Response, Any]:
        return self._request_api(
            Accountv1Api('by_riot_id'),
            game_name=game_name,
            tag_line=tag_line,
        )

    def me(self) -> Union[Response, Any]:
        return self._request_api(
            Accountv1Api('me'),
        )

    def active_shard(self, game: String, puuid: String) -> Union[Response, Any]:
        return self._request_api(
            Accountv1Api('active_shard'),
            game=game,
            puuid=puuid,
        )

